@@ -52,7 +52,7 @@ sub generate_ddl {
 
 sub prepopulate {
    my $self = shift;
-   $self->resultset($_)->delete for qw{Bar Foo Gnarly_Station Gnarly Station};
+   $self->resultset($_)->delete for qw{Bar Foo Gnarly_Station Bloaty Gnarly Station};
 
    $self->populate( Gnarly => [
       [qw{id name}],
@@ -76,6 +76,15 @@ sub prepopulate {
       [3,1],
    ]);
 
+   $self->populate(Bloaty => [
+      [qw{id name}],
+      [1,1],
+      [2,2],
+      [3,3],
+      [4,4],
+      [5,5],
+   ]);
+
    $self->populate(Foo => [
       [qw{id bar_id}],
       [1,1],
